@@ -13,6 +13,7 @@ import {
   mergePatientDeathData,
   mergePatientFieldValues,
   mergePatientProgramRegistrations,
+  mergePortalUser,
   refreshMultiChildRecordsForSync,
   reconcilePatientFacilities,
   simpleUpdateModels,
@@ -264,6 +265,24 @@ export class PatientMergeMaintainer extends ScheduledTask {
     return noteRecords;
   }
 
+  async specificUpdate_PortalUser() {
+    const { PortalUser } = this.models;
+    const portalUserMerges = await this.findPendingMergePatients(PortalUser);
+
+    const records = [];
+    for (const { keepPatientId, mergedPatientId } of portalUserMerges) {
+      const mergedPortalUser = await mergePortalUser(
+        this.models,
+        keepPatientId,
+        mergedPatientId,
+      );
+      if (mergedPortalUser) {
+        records.push(mergedPortalUser);
+      }
+    }
+    return records;
+  }
+
   async run() {
     const outcomes = await this.remergePatientRecords();
     log.info('PatientMergeMaintainer finished merging. Records affected:', outcomes);
